Unofficial libimagequant Python Bindings
========================================

[![Documentation](https://img.shields.io/badge/documentation-Read%20the%20Docs-brightgreen.svg?logo=read%20the%20docs&logoColor=white)](http://libimagequant-python.readthedocs.io/)
[![PyPI](https://img.shields.io/pypi/v/libimagequant.svg?logo=python&logoColor=white)](https://pypi.org/project/libimagequant/)
[![License: GNU GPL 3.0](https://img.shields.io/github/license/RoadrunnerWMC/libimagequant-python.svg?logo=gnu&logoColor=white)](https://www.gnu.org/licenses/gpl-3.0)

This repository is the home of the unofficial Python bindings for
[libimagequant](https://pngquant.org/lib/).

Full documentation, including setup and usage instructions, is available on
[Read the Docs](http://libimagequant-python.readthedocs.io/).


License
-------

Licensed under the GNU GPL v3. See the `LICENSE` file for the full license
text.
